@@ -91,7 +91,7 @@ will pass once I've fixed the bug
 
 =head1 SOURCE CODE REPOSITORY
 
-L<http://www.cantrell.org.uk/cgit/cgit.cgi/perlmodules/>
+L<git://github.com/DrHyde/perl-modules-CPAN-FindDependencies.git>
 
 =head1 SEE ALSO
 
